@@ -42,7 +42,7 @@ def openDb():
     cursor=database.cursor()
     cursor.execute('''create table if not exists owners (stickid text, uuid text, tatoo text, student text)''')
     cursor.execute('''create table if not exists version (major text, minor text)''')
-    cursor.execute('''create table if not exists preferences (checkable int, workdir text)''')
+    cursor.execute('''create table if not exists preferences (checkable int, mv int, workdir text, manfile text, refresh_enabled int, refresh_delay int)''')
     database.commit()
     checkVersion(version.major(), version.minor())
 
@@ -68,6 +68,16 @@ def checkVersion(major, minor):
                           where major=?""", (version.minor(), version.major()))
     database.commit()
 
+def hasStudent(student):
+    """
+    vérifie qu'un étudiant est déjà connu
+    @param student propriétaire du baladeur
+    @return True si le propriétaire existe déjà
+    """
+    global cursor
+    cursor.execute("select * from owners where student=?", (student,))
+    return cursor.fetchone() != None
+    
 def knowsId(stickid, uuid,tattoo):
     """
     dit si une clé USB est déjà connue
@@ -107,15 +117,31 @@ def readPrefs():
     @return un dictionnaire de préférences
     """
     global cursor
-    cursor.execute("select checkable, workdir from preferences")
+    cursor.execute("select checkable, mv, workdir, manfile, refresh_enabled, refresh_delay from preferences")
     s = cursor.fetchone()
     if s != None:
-        checkable = s[0]==1
-        workdir = s[1]
-        return {"checkable": checkable, "workdir": workdir}
+        checkable      = s[0]==1
+        mv             = s[1]==1
+        workdir        = s[2]
+        manfile        = s[3]
+        refreshEnabled = s[4]==1
+        refreshDelay   = s[5]
+        return {"checkable"     : checkable,
+                "mv"            : mv,
+                "workdir"       : workdir,
+                "manfile"       : manfile,
+                "refreshEnabled": refreshEnabled,
+                "refreshDelay"  : refreshDelay
+                }
     else:
         # valeur par défaut si la base est vide de préférences
-        return {"checkable": True, "workdir": "Travail"}
+        return {"checkable"     : True,
+                "mv"            : False,
+                "workdir"       : "Travail",
+                "manfile"       : "/usr/share/scolasync/help/manualPage_fr_FR.html",
+                "refreshEnabled": False,
+                "refreshDelay"  : 30
+                }
 
 def setWd(newDir):
     """
@@ -150,15 +176,25 @@ def writePrefs(prefs):
         checkable=1
     else:
         checkable=0
-    cursor.execute("select checkable, workdir from preferences")
+    if prefs["mv"]:
+        mv=1
+    else:
+        mv=0
+    if prefs["refreshEnabled"]:
+        refreshEnabled=1
+    else:
+        refreshEnabled=0
+    cursor.execute("select checkable from preferences")
     s = cursor.fetchone()
+    newValues=(checkable, mv, prefs["workdir"], prefs["manfile"], refreshEnabled, prefs["refreshDelay"])
     if s != None:
         cursor.execute("""update preferences
-                          set checkable=?, workdir=?""",
-                       (checkable, prefs["workdir"]))
+                          set checkable=?, mv=?, workdir=?, manfile=?, refresh_enabled=?, refresh_delay=?""",
+                       newValues)
     else:
         cursor.execute("""insert into preferences
-                          values (?,?)""", (checkable, prefs["workdir"]))
+                          values (?,?,?,?,?,?)""",
+                       newValues)
     database.commit()
 
 
