@@ -3,17 +3,17 @@
 <context>
     <name>Aide</name>
     <message>
-        <location filename="../Ui_help.py" line="144"/>
+        <location filename="../Ui_help.py" line="153"/>
         <source>Aide</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../Ui_help.py" line="143"/>
+        <location filename="../Ui_help.py" line="152"/>
         <source>Mode d&apos;emploi</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../Ui_help.py" line="145"/>
+        <location filename="../Ui_help.py" line="155"/>
         <source>ScolaSync, pour gerer les fichiers des baladeurs</source>
         <translation>ScolaSync, pour gérer les fichiers des baladeurs</translation>
     </message>
@@ -23,35 +23,40 @@
         <translation type="obsolete">Numéro de version :</translation>
     </message>
     <message>
-        <location filename="../Ui_help.py" line="147"/>
+        <location filename="../Ui_help.py" line="157"/>
         <source>Auteurs</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../Ui_help.py" line="148"/>
+        <location filename="../Ui_help.py" line="158"/>
         <source>Licence</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../Ui_help.py" line="149"/>
+        <location filename="../Ui_help.py" line="159"/>
         <source>Langues et traductions</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../Ui_help.py" line="150"/>
+        <location filename="../Ui_help.py" line="160"/>
         <source>A propos</source>
         <translation>À propos</translation>
     </message>
     <message>
-        <location filename="../Ui_help.py" line="151"/>
+        <location filename="../Ui_help.py" line="161"/>
         <source>Fermer</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../Ui_help.py" line="146"/>
+        <location filename="../Ui_help.py" line="156"/>
         <source>Numero de version :</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="../Ui_help.py" line="154"/>
+        <source>Manuel</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>Dialog</name>
@@ -76,7 +81,7 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../Ui_chooseInSticks.py" line="157"/>
+        <location filename="../Ui_chooseInSticks.py" line="169"/>
         <source>...</source>
         <translation type="unfinished"></translation>
     </message>
@@ -116,67 +121,62 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainWindow.py" line="154"/>
+        <location filename="../mainWindow.py" line="243"/>
         <source>Double-clic non pris en compte</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainWindow.py" line="154"/>
+        <location filename="../mainWindow.py" line="243"/>
         <source>pas d&apos;action pour l&apos;attribut %1</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainWindow.py" line="285"/>
+        <location filename="../mainWindow.py" line="415"/>
         <source>Veuillez choisir au moins un fichier</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainWindow.py" line="281"/>
+        <location filename="../mainWindow.py" line="411"/>
         <source>Choix de la destination ...</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainWindow.py" line="312"/>
+        <location filename="../mainWindow.py" line="454"/>
         <source>Voir les copies</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainWindow.py" line="317"/>
+        <location filename="../mainWindow.py" line="462"/>
         <source>Destination manquante</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainWindow.py" line="317"/>
+        <location filename="../mainWindow.py" line="462"/>
         <source>Veuillez choisir une destination pour la copie des fichiers</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../Ui_chooseInSticks.py" line="131"/>
+        <location filename="../Ui_chooseInSticks.py" line="143"/>
         <source>Zone de recherche</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../Ui_chooseInSticks.py" line="150"/>
-        <source>Ajouter un fichier ou un filtre</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../Ui_chooseInSticks.py" line="153"/>
+        <location filename="../Ui_chooseInSticks.py" line="165"/>
         <source>Rechercher (fichier) ...</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../Ui_preferences.py" line="57"/>
+        <location filename="../Ui_preferences.py" line="112"/>
         <source>Preferences de ScolaSync</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../Ui_preferences.py" line="58"/>
+        <location filename="../Ui_preferences.py" line="113"/>
         <source>Preferences</source>
         <translation>Préférences</translation>
     </message>
     <message>
-        <location filename="../Ui_preferences.py" line="63"/>
+        <location filename="../Ui_preferences.py" line="121"/>
         <source>Travail</source>
         <translation type="unfinished"></translation>
     </message>
@@ -196,27 +196,27 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ownedUsbDisk.py" line="202"/>
+        <location filename="../ownedUsbDisk.py" line="203"/>
         <source>La cle %1&lt;br&gt;n&apos;est pas identifiee, donnez le nom du proprietaire</source>
         <translation>La clé %1&lt;br&gt;n&apos;est pas identifiée, donnez le nom du propriétaire</translation>
     </message>
     <message>
-        <location filename="../ownedUsbDisk.py" line="203"/>
+        <location filename="../ownedUsbDisk.py" line="204"/>
         <source>Entrer un nom</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainWindow.py" line="243"/>
+        <location filename="../mainWindow.py" line="360"/>
         <source>Vous allez effacer plusieurs baladeurs</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../Ui_chooseInSticks.py" line="130"/>
+        <location filename="../Ui_chooseInSticks.py" line="142"/>
         <source>Choix de fichiers à supprimer</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../Ui_chooseInSticks.py" line="132"/>
+        <location filename="../Ui_chooseInSticks.py" line="144"/>
         <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
 &lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
 p, li { white-space: pre-wrap; }
@@ -226,57 +226,52 @@ p, li { white-space: pre-wrap; }
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../Ui_chooseInSticks.py" line="138"/>
+        <location filename="../Ui_chooseInSticks.py" line="150"/>
         <source>Le répertoire des clés&lt;br&gt;où se trouvent les&lt;br&gt;documents de travail</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../Ui_chooseInSticks.py" line="139"/>
+        <location filename="../Ui_chooseInSticks.py" line="151"/>
         <source>Le répertoire des clés où se trouvent les documents de travail</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../Ui_chooseInSticks.py" line="140"/>
+        <location filename="../Ui_chooseInSticks.py" line="152"/>
         <source>Choix de clé modèle</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../Ui_chooseInSticks.py" line="142"/>
+        <location filename="../Ui_chooseInSticks.py" line="154"/>
         <source>Choisir une des clés</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../Ui_chooseInSticks.py" line="143"/>
+        <location filename="../Ui_chooseInSticks.py" line="155"/>
         <source>Liste de fichiers à traiter (jokers autorisés)</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../Ui_chooseInSticks.py" line="145"/>
+        <location filename="../Ui_chooseInSticks.py" line="157"/>
         <source>Supprimer l&apos;item sélectionné</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../Ui_chooseInSticks.py" line="148"/>
-        <source>Écrire le nom d&apos;un fichier ou d&apos;un répertoire.&lt;br&gt;Jokers autorisés</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message encoding="UTF-8">
-        <location filename="../Ui_chooseInSticks.py" line="156"/>
+        <location filename="../Ui_chooseInSticks.py" line="168"/>
         <source>Rechercher (répertoire) ...</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../Ui_preferences.py" line="60"/>
+        <location filename="../Ui_preferences.py" line="115"/>
         <source>Les cases à cocher permettent de n&apos;agir que sur une part des baladeurs</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../Ui_preferences.py" line="61"/>
+        <location filename="../Ui_preferences.py" line="116"/>
         <source>Utiliser des cases à cocher pour désigner les baladeurs</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../Ui_preferences.py" line="62"/>
+        <location filename="../Ui_preferences.py" line="120"/>
         <source>Répertoire pour les travaux :</source>
         <translation type="unfinished"></translation>
     </message>
@@ -301,32 +296,32 @@ p, li { white-space: pre-wrap; }
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="238"/>
+        <location filename="../mainWindow.py" line="353"/>
         <source>Choix de fichiers à supprimer (jokers autorisés)</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="285"/>
+        <location filename="../mainWindow.py" line="415"/>
         <source>Aucun fichier sélectionné</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="279"/>
+        <location filename="../mainWindow.py" line="409"/>
         <source>Choix de fichiers à copier</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="280"/>
+        <location filename="../mainWindow.py" line="410"/>
         <source>Choix de fichiers à copier depuis les baladeurs</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="293"/>
+        <location filename="../mainWindow.py" line="423"/>
         <source>Choisir un répertoire de destination</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="312"/>
+        <location filename="../mainWindow.py" line="454"/>
         <source>Voulez-vous voir les fichiers copiés ?</source>
         <translation type="unfinished"></translation>
     </message>
@@ -335,59 +330,124 @@ p, li { white-space: pre-wrap; }
         <source>%s méga-octets</source>
         <translation type="unfinished"></translation>
     </message>
+    <message encoding="UTF-8">
+        <location filename="../Ui_preferences.py" line="122"/>
+        <source>Fichier spécial pour le manuel :</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../Ui_preferences.py" line="123"/>
+        <source>/usr/share/scolasync/help/manualPage_fr_FR.html</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message encoding="UTF-8">
+        <location filename="../Ui_preferences.py" line="124"/>
+        <source>Recomptage automatique des médias :</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../Ui_preferences.py" line="125"/>
+        <source>toutes les</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../Ui_preferences.py" line="126"/>
+        <source>30 secondes</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../preferences.py" line="53"/>
+        <source>%1 secondes</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message encoding="UTF-8">
+        <location filename="../Ui_chooseInSticks.py" line="163"/>
+        <source>Ligne d&apos;édition du nom d&apos;un fichier ou d&apos;un répertoire.&lt;br&gt;Jokers autorisés</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message encoding="UTF-8">
+        <location filename="../Ui_chooseInSticks.py" line="160"/>
+        <source>Ajouter un fichier ou un filtre défini dans la ligne d&apos;édition</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message encoding="UTF-8">
+        <location filename="../mainWindow.py" line="486"/>
+        <source>Réitérer la dernière commande</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message encoding="UTF-8">
+        <location filename="../mainWindow.py" line="486"/>
+        <source>La dernière commande était&lt;br&gt;%1&lt;br&gt;Voulez-vous la relancer avec les nouveaux baladeurs ?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message encoding="UTF-8">
+        <location filename="../Ui_preferences.py" line="119"/>
+        <source>Efface les fichiers et les répertoires après copie</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message encoding="UTF-8">
+        <location filename="../Ui_preferences.py" line="117"/>
+        <source>Si la case est cochée,&lt;br&gt;les données sont transférées sur le disque dur&lt;br&gt;puis effacée des baladeurs.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message encoding="UTF-8">
+        <location filename="../Ui_preferences.py" line="118"/>
+        <source>Si la case est cochée, les données sont transférées sur le disque dur puis effacée des baladeurs.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context encoding="UTF-8">
     <name>Main</name>
     <message encoding="UTF-8">
-        <location filename="../help.py" line="39"/>
+        <location filename="../help.py" line="41"/>
         <source>Version numéro %1.%2</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="337"/>
+        <location filename="../mainWindow.py" line="514"/>
         <source>Démontage des baladeurs</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="337"/>
+        <location filename="../mainWindow.py" line="514"/>
         <source>Êtes-vous sûr de vouloir démonter tous les baladeurs cochés de la liste ?</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="477"/>
-        <source>Cocher ou décocher cette case en cliquant.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="479"/>
+        <location filename="../mainWindow.py" line="734"/>
         <source>Propriétaire de la clé USB ou du baladeur ;&lt;br&gt;&lt;b&gt;Double-clic&lt;/b&gt; pour modifier.</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="481"/>
+        <location filename="../mainWindow.py" line="736"/>
         <source>Point de montage de la clé USB ou du baladeur ;&lt;br&gt;&lt;b&gt;Double-clic&lt;/b&gt; pour voir les fichiers.</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="483"/>
+        <location filename="../mainWindow.py" line="738"/>
         <source>Capacité de la clé USB ou du baladeur en kO ;&lt;br&gt;&lt;b&gt;Double-clic&lt;/b&gt; pour voir la place occupée.</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="485"/>
+        <location filename="../mainWindow.py" line="740"/>
         <source>Fabricant de la clé USB ou du baladeur.</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="487"/>
+        <location filename="../mainWindow.py" line="742"/>
         <source>Modèle de la clé USB ou du baladeur.</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="489"/>
+        <location filename="../mainWindow.py" line="744"/>
         <source>Numéro de série de la clé USB ou du baladeur.</source>
         <translation type="unfinished"></translation>
     </message>
+    <message encoding="UTF-8">
+        <location filename="../mainWindow.py" line="732"/>
+        <source>Cocher ou décocher cette case en cliquant.&lt;br&gt;&lt;b&gt;Double-clic&lt;/b&gt; pour agir sur plusieurs baladeurs.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>MainWindow</name>
@@ -397,7 +457,7 @@ p, li { white-space: pre-wrap; }
         <translation>Taille du disque</translation>
     </message>
     <message>
-        <location filename="../Ui_mainWindow.py" line="143"/>
+        <location filename="../Ui_mainWindow.py" line="160"/>
         <source>...</source>
         <translation type="unfinished"></translation>
     </message>
@@ -412,12 +472,12 @@ p, li { white-space: pre-wrap; }
         <translation>Utilisé(s)</translation>
     </message>
     <message>
-        <location filename="../Ui_mainWindow.py" line="119"/>
+        <location filename="../Ui_mainWindow.py" line="133"/>
         <source>ScolaSync</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../Ui_mainWindow.py" line="120"/>
+        <location filename="../Ui_mainWindow.py" line="134"/>
         <source>Actions</source>
         <translation type="unfinished"></translation>
     </message>
@@ -442,43 +502,111 @@ p, li { white-space: pre-wrap; }
         <translation type="obsolete">Préférences</translation>
     </message>
     <message>
-        <location filename="../Ui_mainWindow.py" line="142"/>
+        <location filename="../Ui_mainWindow.py" line="159"/>
         <source>Aide</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../Ui_mainWindow.py" line="137"/>
+        <location filename="../Ui_mainWindow.py" line="153"/>
         <source>Force à recompter les baladeurs</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../Ui_mainWindow.py" line="140"/>
+        <location filename="../Ui_mainWindow.py" line="151"/>
         <source>Affiche le nombre de baladeurs connectés</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <location filename="../Ui_mainWindow.py" line="122"/>
-        <source>Copier depuis les baladeurs</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../Ui_mainWindow.py" line="125"/>
-        <source>Copier vers les baladeurs</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../Ui_mainWindow.py" line="128"/>
-        <source>Effacer des fichiers ou des dossiers dans les baladeurs</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../Ui_mainWindow.py" line="131"/>
-        <source>Demonter les baladeurs</source>
+    <message encoding="UTF-8">
+        <location filename="../Ui_mainWindow.py" line="156"/>
+        <source>Préférences</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../Ui_mainWindow.py" line="134"/>
-        <source>Préférences</source>
+        <location filename="../mainWindow.py" line="165"/>
+        <source>Refaire à nouveau</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message encoding="UTF-8">
+        <location filename="../mainWindow.py" line="166"/>
+        <source>Refaire à nouveau la dernière opération réussie, avec les baladeurs connectés plus récemment</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message encoding="UTF-8">
+        <location filename="../Ui_mainWindow.py" line="145"/>
+        <source>Éjecter les baladeurs sélectionnés</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message encoding="UTF-8">
+        <location filename="../Ui_mainWindow.py" line="136"/>
+        <source>Copier depuis les baladeurs sélectionnés</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message encoding="UTF-8">
+        <location filename="../Ui_mainWindow.py" line="139"/>
+        <source>Copier vers les baladeurs sélectionnés</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message encoding="UTF-8">
+        <location filename="../Ui_mainWindow.py" line="142"/>
+        <source>Effacer des fichiers ou des dossiers dans les baladeurs sélectionnés</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message encoding="UTF-8">
+        <location filename="../mainWindow.py" line="167"/>
+        <source>Arrêter les opérations en cours</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message encoding="UTF-8">
+        <location filename="../mainWindow.py" line="168"/>
+        <source>Essaie d&apos;arrêter les opérations en cours. À faire seulement si celles-ci durent trop longtemps</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>checkBoxDialog</name>
+    <message encoding="UTF-8">
+        <location filename="../checkBoxDialog.ui" line="14"/>
+        <source>Gestion des cases à cocher</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../checkBoxDialog.ui" line="27"/>
+        <source>Cocher tous les baladeurs</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../checkBoxDialog.ui" line="30"/>
+        <source>Tout cocher</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message encoding="UTF-8">
+        <location filename="../checkBoxDialog.ui" line="44"/>
+        <source>Inverser le choix de baladeurs&lt;br&gt;Les baladeurs cochés seront décochés, et inversement</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../checkBoxDialog.ui" line="47"/>
+        <source>Inverser le choix</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message encoding="UTF-8">
+        <location filename="../checkBoxDialog.ui" line="61"/>
+        <source>Désélectionner les baladeurs</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../checkBoxDialog.ui" line="64"/>
+        <source>Ne rien cocher</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../checkBoxDialog.ui" line="78"/>
+        <source>Ne rien faire</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message encoding="UTF-8">
+        <location filename="../checkBoxDialog.ui" line="81"/>
+        <source>Échappement</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
