@@ -26,37 +26,34 @@ licence['en']="""
 from PyQt4.QtCore import *
 from PyQt4.QtGui import *
 import ownedUsbDisk, help, copyToDialog1, chooseInSticks, usbThread
-import diskFull, preferences
+import diskFull, preferences, checkBoxDialog
 import os.path, operator, subprocess, dbus, re, time, copy
 from notification import Notification
 import db
-from globaldef import logFileName
+import deviceListener
+from globaldef import logFileName, _dir
 
 # cette donnée est globale, pour être utilisé depuis n'importe quel objet
 qApp.diskData=ownedUsbDisk.Available(True,access="firstFat")
 
-def firstdir(l):
-    """
-    Renvoie le premier répertoire existant d'une liste de propositions
-    @param l la liste de propositions
-    """
-    for d in l:
-        if os.path.isdir(d): return d
-    return None
-   
-def _dir(which):
-    """
-    Renvoie le répertoire où trouver telle ou telle ressource
-    @param which le type de ressource
-    """
-    if which=="lang":
-        return firstdir(["/usr/share/scolasync/lang", "lang"])
-    elif which=="help":
-        return firstdir(["/usr/share/scolasync/help", "help"])
-    elif which=="share":
-        return firstdir(["/usr/share/scolasync/","share"])
-    return None
+activeThreads={} # donnée globale : les threads actifs
+# cette donnée est mise à jour par des signaux émis au niveau des threads
+# et elle est utilisée par la routine de traçage des cases du tableau
+pastCommands={}  # donnée globale : les commandes réalisées dans le passé
+lastCommand=None # donnée globale : la toute dernière commande
 
+def registerCmd(cmd,partition):
+    """
+    enregistre la commande cmd pour la partition donnée
+    @param cmd une commande pour créer un thread t
+    @param partition une partition
+    """
+    global pastCommands, lastCommand
+    if pastCommands.has_key(cmd):
+        pastCommands[cmd].append(partition.owner)
+    else:
+        pastCommands[cmd]=[partition.owner]
+    lastCommand=cmd
 
 class mainWindow(QMainWindow):
     def __init__(self, parent, opts, locale="fr_FR"):
@@ -72,14 +69,22 @@ class mainWindow(QMainWindow):
         from Ui_mainWindow  import Ui_MainWindow
         self.ui = Ui_MainWindow()
         self.ui.setupUi(self)
+        # initialise deux icônes
+        self.initRedoStuff()
+        # initialise le tableau
         self.t=self.ui.tableView
+        self.proxy=QSortFilterProxyModel()
+        self.proxy.setSourceModel(self.t.model())
         self.opts=opts
-        self.applyPreferences()
         self.timer=QTimer()
+        self.applyPreferences()
+        self.listener=deviceListener.DeviceListener(self)
         self.updateButtons()
-        self.oldThreads=set()
+        self.operations=[] # liste des opérations précédemment "réussies"
+        self.oldThreads=set() # threads lancés éventuellement encore vivants
         self.flashTimer=QTimer()
         self.flashTimer.setSingleShot(True)
+        self.checkDisksLock=False # autorise self.checkDisks
         QObject.connect(self.ui.forceCheckButton, SIGNAL("clicked()"), self.checkDisks)
         QObject.connect(self.timer, SIGNAL("timeout()"), self.checkDisks)
         QObject.connect(self.flashTimer, SIGNAL("timeout()"), self.normalLCD);
@@ -88,8 +93,79 @@ class mainWindow(QMainWindow):
         QObject.connect(self.ui.toButton, SIGNAL("clicked()"), self.copyTo)
         QObject.connect(self.ui.fromButton, SIGNAL("clicked()"), self.copyFrom)
         QObject.connect(self.ui.delButton, SIGNAL("clicked()"), self.delFiles)
+        QObject.connect(self.ui.redoButton, SIGNAL("clicked()"), self.redoCmd)
         QObject.connect(self.ui.preferenceButton, SIGNAL("clicked()"), self.preference)
         QObject.connect(self.ui.tableView, SIGNAL("doubleClicked(const QModelIndex&)"), self.tableClicked)
+        QObject.connect(self,SIGNAL("deviceAdded(QString)"), self.deviceAdded)
+        QObject.connect(self,SIGNAL("deviceRemoved(QString)"), self.deviceRemoved)
+        QObject.connect(self,SIGNAL("checkAll()"), self.checkAll)
+        QObject.connect(self,SIGNAL("checkToggle()"), self.checkToggle)
+        QObject.connect(self,SIGNAL("checkNone()"), self.checkNone)
+
+    def checkModify(self, boolFunc):
+        """
+        @param boolfunc une fonction pour décider du futur état de la coche
+        étant donné l'état antérieur
+        Modifie les coches des baladeurs
+        """
+        model=self.tm
+        index0=model.createIndex(0,0)
+        index1=model.createIndex(len(model.donnees)-1,0)
+        srange=QItemSelectionRange(index0,index1)
+        for i in srange.indexes():
+            checked=i.model().data(i,Qt.DisplayRole).toBool()
+            model.setData(i, boolFunc(checked),Qt.EditRole)
+
+    def checkAll(self):
+        """
+        Coche tous les baladeurs
+        """
+        self.checkModify(lambda x: True)
+        
+    def checkToggle(self):
+        """
+        Inverse la coche des baladeurs
+        """
+        self.checkModify(lambda x: not x)
+       
+    def checkNone(self):
+        """
+        Décoche tous les baladeurs
+        """
+        self.checkModify(lambda x: False)
+        
+    def deviceAdded(self, s):
+        """
+        fonction de rappel pour un medium ajouté
+        @param s chemin UDisks, exemple : /org/freedesktop/UDisks/devices/sdb3
+        """
+        ## print "dans deviceAdded", s
+        if self.listener.vfatUsbPath(str(s)):
+            self.checkDisks(noLoop=True)
+        
+    def deviceRemoved(self, s):
+        """
+        fonction de rappel pour un medium retiré
+        @param s une chaine de caractères du type /dev/sdxy
+        """
+        ## print "dans deviceRemoved", s
+        if qApp.diskData.hasDev(s):
+            self.checkDisks()
+        
+    def initRedoStuff(self):
+        """
+        Initialise des données pour le bouton central (refaire/stopper)
+        """
+        # réserve les icônes
+        self.iconRedo = QIcon()
+        self.iconRedo.addPixmap(QPixmap("/usr/share/icons/Tango/scalable/actions/go-jump.svg"), QIcon.Normal, QIcon.Off)
+        self.iconStop = QIcon()
+        self.iconStop.addPixmap(QPixmap("/usr/share/icons/Tango/scalable/actions/stop.svg"), QIcon.Normal, QIcon.Off)
+        # réserve les phrases d'aide
+        self.redoToolTip=QApplication.translate("MainWindow", "Refaire à nouveau", None, QApplication.UnicodeUTF8)
+        self.redoStatusTip=QApplication.translate("MainWindow", "Refaire à nouveau la dernière opération réussie, avec les baladeurs connectés plus récemment", None, QApplication.UnicodeUTF8)
+        self.stopToolTip=QApplication.translate("MainWindow", "Arrêter les opérations en cours", None, QApplication.UnicodeUTF8)
+        self.stopStatusTip=QApplication.translate("MainWindow", "Essaie d'arrêter les opérations en cours. À faire seulement si celles-ci durent trop longtemps", None, QApplication.UnicodeUTF8)
 
     def showEvent (self, ev):
         """
@@ -98,26 +174,37 @@ class mainWindow(QMainWindow):
         après construction de la fenêtre seulement
         """
         result=QMainWindow.showEvent(self, ev)
-        self.timer.start(20000)
+        self.setTimer()
         self.checkDisks(force=True) # met à jour le compte de disques affiché
         return result
-        
+
+    def setTimer(self, enabled=True):
+        """
+        sets the main timer
+        """
+        if self.refreshEnabled:
+            self.timer.start(self.refreshDelay*1000)
+        else:
+            self.timer.stop()
+
     def applyPreferences(self):
         """
         Applique les préférences et les options de ligne de commande
         """
         prefs=db.readPrefs()
         self.workdir=prefs["workdir"]
+        self.refreshEnabled=prefs["refreshEnabled"]
+        self.refreshDelay=prefs["refreshDelay"]
+        self.setTimer()
+        self.manFileLocation=prefs["manfile"]
         # on active les cases à cocher si ça a été réclamé par les options
         # ou par les préférences
         self.checkable=("--check","") in self.opts or ("-c","") in self.opts or prefs["checkable"]
+        self.mv=prefs["mv"]
         other=ownedUsbDisk.Available(self.checkable,access="firstFat")
         qApp.diskData=other
         self.header=ownedUsbDisk.uDisk.headers(self.checkable)
         self.connectTableModel(other)
-        # met en ordre par la colonne des propriétaires
-        self.t.setSortingEnabled(True)
-        self.t.resizeColumnsToContents()
 
     def changeWd(self, newDir):
         """
@@ -133,14 +220,16 @@ class mainWindow(QMainWindow):
         @param idx un QModelIndex
         """
         c=idx.column()
-        r=idx.row()
+        mappedIdx=self.proxy.mapFromSource(idx)
+        r=mappedIdx.row()
+        ## print "row=%d mapped row=%d" %(idx.row(), r)
         h=self.header[c]
         if c==0 and self.checkable:
-            # case à cocher
+            self.manageCheckBoxes()
             pass
-        elif c==1:
+        elif c==1 or (c==0 and not self.checkable):
             # case du propriétaire
-            self.editOwner(r)
+            self.editOwner(mappedIdx)
         elif "device-mount-paths" in h:
             cmd=u"nautilus '%s'" %idx.data().toString ()
             subprocess.call(cmd, shell=True)
@@ -155,6 +244,13 @@ class mainWindow(QMainWindow):
                                 QApplication.translate("Dialog","Double-clic non pris en compte",None, QApplication.UnicodeUTF8),
                                 QApplication.translate("Dialog","pas d'action pour l'attribut %1",None, QApplication.UnicodeUTF8).arg(h))
 
+    def manageCheckBoxes(self):
+        """
+        ouvre un dialogue pour permettre de gérer les cases à cocher globalement
+        """
+        cbDialog=checkBoxDialog.CheckBoxDialog(self)
+        cbDialog.exec_()
+        
     def diskSizeData(self, rowOrDev):
         """
         @param rowOrDev a row number in the tableView, or a device string
@@ -172,16 +268,20 @@ class mainWindow(QMainWindow):
         return m
 
 
-    def diskFromTableRow(self,ligne):
+    def diskFromOwner(self,student):
         """
-        trouve le disque qui correspond à une ligne du tableau
-        @param ligne la ligne du tableau qui concerne une clé
-        @return le disque correspondant à la ligne de tableau (type uDisk)
+        trouve le disque qui correspond à un propriétaire
+        @param student le propriétaire du disque
+        @return le disque correspondant à l'étudiant
         """
-        stickid=qApp.diskData[ligne][self.header.index("5drive-serial")]
         found=False
         for d in qApp.diskData.disks.keys():
-            if d.showableProp("drive-serial")==stickid:
+            if d.owner==student:
+                found=True
+                break
+            # si on ne trouve pas avec le nom, on essaie de trouver
+            # un disque encore inconnu, le premier venu
+            if d.owner==None or len(d.owner)==0:
                 found=True
                 break
         if found:
@@ -189,16 +289,17 @@ class mainWindow(QMainWindow):
         else:
             return None
         
-    def editOwner(self, ligne):
+    def editOwner(self, idx):
         """
         Édition du propriétaire d'une clé.
-        @param ligne la ligne du tableau qui concerne une clé
+        @param idx un QModelIndex qui pointe sur le propriétaire d'une clé
         """
-        student=qApp.diskData[ligne][1]
-        ownedUsbDisk.editRecord(self.diskFromTableRow(ligne), student)
+        student=u"%s" %self.tm.data(idx,Qt.DisplayRole).toString()
+        ownedUsbDisk.editRecord(self.diskFromOwner(student), prompt=student)
         other=ownedUsbDisk.Available(self.checkable,access="firstFat")
         qApp.diskData=other
         self.connectTableModel(other)
+        self.checkDisks()
         
     def updateButtons(self):
         """
@@ -208,14 +309,28 @@ class mainWindow(QMainWindow):
         active. Par contre démonter les clés quand elles sont absentes ça
         n'a pas d'utilité.
         """
-        if len(qApp.diskData)>0:
-            self.ui.toButton.setEnabled(True)
-            self.ui.fromButton.setEnabled(True)
-            self.ui.umountButton.setEnabled(True)
+        global activeThreads, lastCommand
+        active = len(qApp.diskData)>0
+        for button in (self.ui.toButton,
+                       self.ui.fromButton,
+                       self.ui.delButton,
+                       self.ui.umountButton):
+            button.setEnabled(active)
+        # l'état du redoButton dépend de plusieurs facteurs
+        # si un thread au moins est en cours, on y affiche un STOP actif
+        # sinon on y met l'icône de lastCommand, et celle-ci sera active
+        # seulement s'il y a une commande déjà validée
+        if len(activeThreads) > 0:
+            self.ui.redoButton.setIcon(self.iconStop)
+            self.ui.redoButton.setToolTip(self.stopToolTip)
+            self.ui.redoButton.setStatusTip(self.stopStatusTip)
+            self.ui.redoButton.setEnabled(True)
         else:
-            self.ui.toButton.setEnabled(False)
-            self.ui.fromButton.setEnabled(False)
-            self.ui.umountButton.setEnabled(False)
+            self.oldThreads=set() # vide l'ensemble puisque tout est fini
+            self.ui.redoButton.setIcon(self.iconRedo)
+            self.ui.redoButton.setToolTip(self.redoToolTip)
+            self.ui.redoButton.setStatusTip(self.redoStatusTip)
+            self.ui.redoButton.setEnabled(lastCommand!=None)
 
     def preference(self):
         """
@@ -229,7 +344,7 @@ class mainWindow(QMainWindow):
             db.writePrefs(pref.values())
             # on applique les préférences tout de suite sans redémarrer
             self.applyPreferences()
-            
+
     def delFiles(self):
         """
         Lance l'action de supprimer des fichiers ou des répertoires dans les clés USB
@@ -240,19 +355,29 @@ class mainWindow(QMainWindow):
         ok = d.exec_()
         if ok:
             pathList=map(lambda x: u"%s" %x, d.pathList())
-            reply=QMessageBox.critical(None,
-                                       QApplication.translate("Dialog","Vous allez effacer plusieurs baladeurs",None, QApplication.UnicodeUTF8),
-                                       QApplication.translate("Dialog","Etes-vous certain de vouloir effacer : "+",".join(pathList),None, QApplication.UnicodeUTF8))
+            buttons=QMessageBox.Ok|QMessageBox.Cancel
+            defaultButton=QMessageBox.Cancel
+            reply=QMessageBox.warning(
+                None,
+                QApplication.translate("Dialog","Vous allez effacer plusieurs baladeurs",None, QApplication.UnicodeUTF8),
+                QApplication.translate("Dialog","Etes-vous certain de vouloir effacer : "+"\n".join(pathList),None, QApplication.UnicodeUTF8),
+                buttons, defaultButton)
             if reply == QMessageBox.Ok:
+                cmd='t=usbThread.threadDeleteInUSB(p,%s,subdir="Travail", logfile="%s", parent=self.tm)' %(pathList,logFileName)
                 for p in qApp.diskData:
-                    t=usbThread.threadDeleteInUSB(p,pathList,subdir="Travail", logfile=logFileName)
+                    if not p.selected: continue # pas les médias désélectionnés
+                    registerCmd(cmd,p)
+                    exec(compile(cmd,'<string>','exec'))
                     t.setDaemon(True)
                     t.start()
-                self.checkDisks() # met à jour les symboles d'activité
+                    self.oldThreads.add(t)
+            return True
         else:
-            msgBox=QMessageBox.warning(None,
-                                       QApplication.translate("Dialog","Aucun fichier sélectionné",None, QApplication.UnicodeUTF8),
-                                       QApplication.translate("Dialog","Veuillez choisir au moins un fichier",None, QApplication.UnicodeUTF8))
+            msgBox=QMessageBox.warning(
+                None,
+                QApplication.translate("Dialog","Aucun fichier sélectionné",None, QApplication.UnicodeUTF8),
+                QApplication.translate("Dialog","Veuillez choisir au moins un fichier",None, QApplication.UnicodeUTF8))
+            return True
 
     def copyTo(self):
         """
@@ -261,16 +386,21 @@ class mainWindow(QMainWindow):
         d=copyToDialog1.copyToDialog1(parent=self, workdir=self.workdir)
         d.exec_()
         if d.ok==True:
+            cmd='t=usbThread.threadCopyToUSB(p,%s,subdir="%s", logfile="%s", parent=self.tm)' %(d.selectedList(), self.workdir, logFileName)
             for p in qApp.diskData:
-                subdir=self.workdir
-                t=usbThread.threadCopyToUSB(p,d.selectedList(),subdir=subdir, logfile=logFileName)
+                if not p.selected: continue # pas les médias désélectionnés
+                registerCmd(cmd,p)
+                exec(compile(cmd,'<string>','exec'))
                 t.setDaemon(True)
                 t.start()
-            self.checkDisks() # met à jour les symboles d'activité
+                self.oldThreads.add(t)
+            return True
         else:
-            msgBox=QMessageBox.warning(None,
-                                       QApplication.translate("Dialog","Aucun fichier sélectionné",None, QApplication.UnicodeUTF8),
-                                       QApplication.translate("Dialog","Veuillez choisir au moins un fichier",None, QApplication.UnicodeUTF8))
+            msgBox=QMessageBox.warning(
+                None,
+                QApplication.translate("Dialog","Aucun fichier sélectionné",None, QApplication.UnicodeUTF8),
+                QApplication.translate("Dialog","Veuillez choisir au moins un fichier",None, QApplication.UnicodeUTF8))
+            return True
 
     def copyFrom(self):
         """
@@ -285,47 +415,93 @@ class mainWindow(QMainWindow):
             msgBox=QMessageBox.warning(None,
                                        QApplication.translate("Dialog","Aucun fichier sélectionné",None, QApplication.UnicodeUTF8),
                                        QApplication.translate("Dialog","Veuillez choisir au moins un fichier",None, QApplication.UnicodeUTF8))
-            return
+            return True
         # bon, alors c'est OK pour le choix des fichiers à envoyer
         pathList=map(lambda x: u"%s" %x, d.pathList())
         mp=d.selectedDiskMountPoint()
         initialPath=os.path.expanduser("~")
-        destDir = QFileDialog.getExistingDirectory(None,
-                                                   QApplication.translate("Dialog","Choisir un répertoire de destination",None, QApplication.UnicodeUTF8),
-                                                   initialPath)
+        destDir = QFileDialog.getExistingDirectory(
+            None,
+            QApplication.translate("Dialog","Choisir un répertoire de destination",None, QApplication.UnicodeUTF8),
+            initialPath)
         if destDir and len(destDir)>0 :
-            dest=u"%s" %destDir
+            if self.mv:
+                cmd=u"""t=usbThread.threadMoveFromUSB(
+                           p,%s,subdir=self.workdir,
+                           rootPath="%s", dest="%s", logfile="%s",
+                           parent=self.tm)""" %(pathList, mp, destDir, logFileName)
+            else:
+                cmd=u"""t=usbThread.threadCopyFromUSB(
+                           p,%s,subdir=self.workdir,
+                           rootPath="%s", dest="%s", logfile="%s",
+                           parent=self.tm)""" %(pathList, mp, destDir, logFileName)
+                
             for p in qApp.diskData:
+                if not p.selected: continue # pas les médias désélectionnés
                 # on devrait vérifier s'il y a des données à copier
                 # et s'il n'y en a pas, ajouter des lignes au journal
                 # mais on va laisser faire ça dans le thread
                 # inconvénient : ça crée quelquefois des sous-répertoires
                 # vides inutiles dans le répertoire de destination.
-                t=usbThread.threadCopyFromUSB(p,pathList,subdir=self.workdir,
-                                              rootPath=mp,
-                                              dest=dest,
-                                              logfile=logFileName)
+                registerCmd(cmd,p)
+                exec(compile(cmd,'<string>','exec'))
                 t.setDaemon(True)
                 t.start()
-            self.checkDisks() # met à jour les symboles d'activité
+                self.oldThreads.add(t)
             # on ouvre nautilus pour voir le résultat des copies
-            if QMessageBox.question(None,
-                                    QApplication.translate("Dialog","Voir les copies",None, QApplication.UnicodeUTF8),
-                                    QApplication.translate("Dialog","Voulez-vous voir les fichiers copiés ?",None, QApplication.UnicodeUTF8)):
-                subprocess.call("nautilus '%s'" %dest,shell=True)
+            buttons=QMessageBox.Ok|QMessageBox.Cancel
+            defaultButton=QMessageBox.Cancel
+            if QMessageBox.question(
+                None,
+                QApplication.translate("Dialog","Voir les copies",None, QApplication.UnicodeUTF8),
+                QApplication.translate("Dialog","Voulez-vous voir les fichiers copiés ?",None, QApplication.UnicodeUTF8),
+                buttons, defaultButton)==QMessageBox.Ok:
+                subprocess.call("nautilus '%s'" %destDir,shell=True)
+            return True
         else:
-            msgBox=QMessageBox.warning(None,
-                                       QApplication.translate("Dialog","Destination manquante",None, QApplication.UnicodeUTF8),
-                                       QApplication.translate("Dialog","Veuillez choisir une destination pour la copie des fichiers",None, QApplication.UnicodeUTF8))
+            msgBox=QMessageBox.warning(
+                None,
+                QApplication.translate("Dialog","Destination manquante",None, QApplication.UnicodeUTF8),
+                QApplication.translate("Dialog","Veuillez choisir une destination pour la copie des fichiers",None, QApplication.UnicodeUTF8))
+            return True
 
-    
+    def redoCmd(self):
+        """
+        Relance la dernière commande, mais en l'appliquant seulement aux
+        baladeurs nouvellement branchés.
+        """
+        global lastCommand, pastCommands, activeThreads
+        if len(activeThreads)>0:
+            print "GRRRR il faut stopper des threads", self.oldThreads
+            for thread in self.oldThreads:
+                if thread.isAlive():
+                    try:
+                        thread._Thread__stop()
+                        print str(thread.getName()) + ' is terminated'
+                    except:
+                        print str(thread.getName()) + ' could not be terminated'
+        else:
+            if lastCommand==None:
+                return
+            if QMessageBox.question(
+                None,
+                QApplication.translate("Dialog","Réitérer la dernière commande",None, QApplication.UnicodeUTF8),
+                QApplication.translate("Dialog","La dernière commande était<br>%1<br>Voulez-vous la relancer avec les nouveaux baladeurs ?",None, QApplication.UnicodeUTF8).arg(lastCommand))==QMessageBox.Cancel:
+                return
+            for p in qApp.diskData:
+                if p.owner in pastCommands[lastCommand] : continue
+                exec(compile(lastCommand,'<string>','exec'))
+                t.setDaemon(True)
+                t.start()
+                self.oldThreads.add(t)
+                pastCommands[lastCommand].append(p.owner)
+        
 
     def help(self):
         """
         Affiche le widget d'aide
         """
-        w=help.helpWindow(None)
-        w.loadBrowsers(_dir("help"),self.locale)
+        w=help.helpWindow(self)
         w.show()
         w.exec_()
 
@@ -333,11 +509,13 @@ class mainWindow(QMainWindow):
         """
         Démonte et détache les clés USB affichées
         """
-        buttons=QMessageBox.StandardButtons(QMessageBox.Ok+QMessageBox.Cancel)
-        button=QMessageBox.critical ( self,
-                                      QApplication.translate("Main","Démontage des baladeurs",None, QApplication.UnicodeUTF8),
-                                      QApplication.translate("Main","Êtes-vous sûr de vouloir démonter tous les baladeurs cochés de la liste ?",None, QApplication.UnicodeUTF8),
-                                      buttons=buttons)
+        buttons=QMessageBox.Ok|QMessageBox.Cancel
+        defaultButton=QMessageBox.Cancel
+        button=QMessageBox.question (
+            self,
+            QApplication.translate("Main","Démontage des baladeurs",None, QApplication.UnicodeUTF8),
+            QApplication.translate("Main","Êtes-vous sûr de vouloir démonter tous les baladeurs cochés de la liste ?",None, QApplication.UnicodeUTF8),
+            buttons,defaultButton)
         if button!=QMessageBox.Ok:
             return
         # on parcourt les premières partition FAT
@@ -350,14 +528,16 @@ class mainWindow(QMainWindow):
                         devfile=partition.getProp("device-file-by-id")
                         if isinstance(devfile, dbus.Array):
                             devfile=devfile[0]
-                        subprocess.call("udisks --unmount %s" %devfile, shell=True)
+                            if partition.isMounted():
+                                subprocess.call("udisks --unmount %s" %devfile, shell=True)
                     # détachement du disque parent
                     devfile_disk=d.getProp("device-file-by-id")
                     if isinstance(devfile_disk, dbus.Array):
                         devfile_disk=devfile_disk[0]
                     subprocess.call("udisks --detach %s" %devfile_disk, shell=True)
                     break
-        self.checkDisks() # remet à jour le compte de disques
+        self.checkDisks()  # remet à jour le compte de disques
+        self.operations=[] # remet à zéro la liste des opérations
                 
 
     def connectTableModel(self, data):
@@ -380,8 +560,10 @@ class mainWindow(QMainWindow):
         else:
             self.t.setItemDelegateForColumn(0, UsbDiskDelegate(self))
             self.t.setItemDelegateForColumn(2, DiskSizeDelegate(self))
+        self.proxy.setSourceModel(self.t.model())
+
         
-    def checkDisks(self, force=False):
+    def checkDisks(self, force=False, noLoop=False):
         """
         fonction relancée périodiquement pour vérifier s'il y a un changement
         dans le baladeurs, et signaler dans le tableau les threads en cours.
@@ -391,24 +573,41 @@ class mainWindow(QMainWindow):
         l'afficheur de nombre de baladeurs connectés et sa valeur est mise à
         jour.
         @param force pour forcer une mise à jour du tableau
+        @param noLoop si False, on ne rentrera pas dans une boucle de Qt
         """
-        other=ownedUsbDisk.Available(self.checkable,access="firstFat")
+        if self.checkDisksLock:
+            # jamais plus d'un appel à la fois pour checkDisks
+            return
+        self.checkDisksLock=True
+        other=ownedUsbDisk.Available(
+            self.checkable,
+            access="firstFat",
+            diskDict=self.listener.connectedVolumes,
+            noLoop=noLoop)
         if force or not self.sameDiskData(qApp.diskData, other):
             qApp.diskData=other
-            self.oldThreads=copy.copy(usbThread.globalThreads.threadSet())
             connectedCount=int(other)
             self.connectTableModel(other)
             self.updateButtons()
             self.t.resizeColumnsToContents()
             self.ui.lcdNumber.display(connectedCount)
         self.flashLCD()
-        self.t.sortByColumn(2)
+        # met la table en ordre par la colonne des propriétaires
+        if self.checkable:
+            col=1
+        else:
+            col=0
+        self.t.horizontalHeader().setSortIndicator(1, Qt.AscendingOrder);
+        self.t.setSortingEnabled(True)
+        self.t.resizeColumnsToContents()
+        self.checkDisksLock=False
+
 
     def sameDiskData(self, one, two):
         """
-        @return True si les ensembles de uniqueId de one et two sont identiques, et si les informations sur les threads n'ont pas varié
+        @return True si les ensembles de uniqueId de one et two sont identiques
         """
-        return set([p.uniqueId() for p in one]) == set([p.uniqueId() for p in two]) and self.oldThreads == usbThread.globalThreads.threadSet()
+        return set([p.uniqueId() for p in one]) == set([p.uniqueId() for p in two])
 
     def flashLCD(self):
         """
@@ -440,6 +639,62 @@ class usbTableModel(QAbstractTableModel):
         self.donnees=donnees
         self.checkable=checkable
         self.pere=parent
+        self.connect(self, SIGNAL("pushCmd(QString, QString)"), self.pushCmd)
+        self.connect(self, SIGNAL("popCmd(QString, QString)"), self.popCmd)
+
+    def pushCmd(self,owner,cmd):
+        """
+        fonction de rappel déclenchée par les threads (au commencement)
+        @param owner le propriétaire du baladeur associé au thread
+        @param cmd la commande shell effectuée sur ce baladeur
+        """
+        global activeThreads, pastCommands, lastCommand
+        owner=u"%s" %owner
+        owner=owner.encode("utf-8")
+        if activeThreads.has_key(owner):
+            activeThreads[owner].append(cmd)
+        else:
+            activeThreads[owner]=[cmd]
+        self.updateOwnerColumn()
+        self.pere.updateButtons()
+
+    def popCmd(self,owner, cmd):
+        """
+        fonction de rappel déclenchée par les threads (à la fin)
+        @param owner le propriétaire du baladeur associé au thread
+        @param cmd la commande shell effectuée sur ce baladeur
+        """
+        global activeThreads, pastCommands, lastCommand
+        owner=u"%s" %owner
+        owner=owner.encode("utf-8")
+        if activeThreads.has_key(owner):
+            cmd0=activeThreads[owner].pop()
+            if cmd0 in cmd:
+                msg=cmd.replace(cmd0,"")+"\n"
+                logFile=open(os.path.expanduser(logFileName),"a")
+                logFile.write(msg)
+                logFile.close()
+            else:
+                raise Exception, (u"mismatched commands\n%s\n%s" %(cmd,cmd0)).encode("utf-8")
+            if len(activeThreads[owner])==0:
+                activeThreads.pop(owner)
+        else:
+            raise Exception, "End of command without a begin."
+        ## print "dans tableModel, popCmd", activeThreads
+        self.updateOwnerColumn()
+        if len(activeThreads)==0 :
+            self.pere.updateButtons()
+
+    def updateOwnerColumn(self):
+        """
+        force la mise à jour de la colonne des propriétaires
+        """
+        if self.checkable:
+            column=1
+        else:
+            column=0
+        self.emit(SIGNAL("dataChanged(QModelIndex, QModelIndex)"), self.index(0,column), self.index(len(self.donnees)-1, column))
+        self.pere.t.viewport().update()
 
     def rowCount(self, parent):
         """
@@ -474,7 +729,7 @@ class usbTableModel(QAbstractTableModel):
             c=index.column()
             h=self.pere.header[c]
             if c==0 and self.checkable:
-                return QApplication.translate("Main","Cocher ou décocher cette case en cliquant.",None, QApplication.UnicodeUTF8)
+                return QApplication.translate("Main","Cocher ou décocher cette case en cliquant.<br><b>Double-clic</b> pour agir sur plusieurs baladeurs.",None, QApplication.UnicodeUTF8)
             elif c==1:
                 return QApplication.translate("Main","Propriétaire de la clé USB ou du baladeur ;<br><b>Double-clic</b> pour modifier.",None, QApplication.UnicodeUTF8)
             elif "device-mount-paths" in h:
@@ -515,10 +770,15 @@ class usbTableModel(QAbstractTableModel):
         self.emit(SIGNAL("layoutChanged()"))
 
 def CheckBoxRect(view_item_style_options):
-  check_box_style_option=QStyleOptionButton()
-  check_box_rect = QApplication.style().subElementRect(QStyle.SE_CheckBoxIndicator,check_box_style_option)
-  check_box_point=QPoint(view_item_style_options.rect.x() + view_item_style_options.rect.width() / 2 - check_box_rect.width() / 2, view_item_style_options.rect.y() + view_item_style_options.rect.height() / 2 - check_box_rect.height() / 2)
-  return QRect(check_box_point, check_box_rect.size())
+    """
+    @param view_item_style_options des options permettant de décider de
+    la taille d'un rectangle
+    @return un QRect dimensionné selon les bonnes options
+    """
+    check_box_style_option=QStyleOptionButton()
+    check_box_rect = QApplication.style().subElementRect(QStyle.SE_CheckBoxIndicator,check_box_style_option)
+    check_box_point=QPoint(view_item_style_options.rect.x() + view_item_style_options.rect.width() / 2 - check_box_rect.width() / 2, view_item_style_options.rect.y() + view_item_style_options.rect.height() / 2 - check_box_rect.height() / 2)
+    return QRect(check_box_point, check_box_rect.size())
 
 class CheckBoxDelegate(QStyledItemDelegate):
     def __init__(self, parent):
@@ -552,12 +812,18 @@ class CheckBoxDelegate(QStyledItemDelegate):
 
         
 class UsbDiskDelegate(QStyledItemDelegate):
+    """
+    Classe pour identifier le baladeur dans le tableau.
+    La routine de rendu à l'écran trace une petite icône et le nom du
+    propriétaire à côté.
+    """
     def __init__(self, parent):
         QStyledItemDelegate.__init__(self,parent)
         self.okPixmap=QPixmap("/usr/share/icons/Tango/16x16/status/weather-clear.png")
         self.busyPixmap=QPixmap("/usr/share/icons/Tango/16x16/actions/view-refresh.png")
 
     def paint(self, painter, option, index):
+        global activeThreads
         text = index.model().data(index, Qt.DisplayRole).toString()
         rect0=QRect(option.rect)
         rect1=QRect(option.rect)
@@ -568,12 +834,18 @@ class UsbDiskDelegate(QStyledItemDelegate):
         rect1.setSize(QSize(w-h,h))
         QApplication.style().drawItemText (painter, rect1, Qt.AlignLeft+Qt.AlignVCenter, option.palette, True, text)
         QApplication.style().drawItemText (painter, rect0, Qt.AlignCenter, option.palette, True, QString("O"))
-        if usbThread.globalThreads.busy(u"%s" %text):
+        text=(u"%s" %text).encode("utf-8")
+        if activeThreads.has_key(text):
             QApplication.style().drawItemPixmap (painter, rect0, Qt.AlignCenter, self.busyPixmap)
         else:
             QApplication.style().drawItemPixmap (painter, rect0, Qt.AlignCenter, self.okPixmap)
         
 class DiskSizeDelegate(QStyledItemDelegate):
+    """
+    Classe pour figurer la taille de la mémoire du baladeur. Trace un petit
+    secteur représentant la place occupée, puis affiche la place avec l'unité
+    le plus parropriée.
+    """
     def __init__(self, parent):
         QStyledItemDelegate.__init__(self,parent)
         
